# = Trialday Base
#
# The Base class contains the integrations between the Application class
# and the router. It uses class methods to, when called, invoke the
# Router.route. This will add the new route to the list of available routes.
# [see Sinatra: lib/sinatra/base.rb#L1599]
#
# = Trialday Delegator
#
# The Delegator dynamic creates the integrations between the public
# api and the Trialday::Application class. It generates get/post methods
# on the fly and by metaprogramming defines what should happen whe the API
# is called. The Application is then registered to accept the parameters,
# calling passing the routes path and body block to the scope.
# [see Sinatra: lib/sinatra/base.rb#L1908]
module Trialday

  class Base
    class << self
      # Defining a `GET` handler
      def get(path, &block)
        Trialday::Router.route(path, 'GET', &block)
      end
      # Defining a `POST` handler
      def post(path, &block)
        Trialday::Router.route(path, 'POST', &block)
      end
    end
  end

  module Delegator #:nodoc:
    def self.delegate(*methods)
      methods.each do |method_name|
        define_method(method_name) do |*args, &block|
          Trialday::Application.send(method_name, *args, &block)
        end
      end
    end

    delegate :get, :post
  end
end